@@ -11,6 +11,7 @@ import yaml
 
 from doorstop import common
 from doorstop.common import DoorstopError
+from doorstop import settings
 
 
 def auto_load(func):
@@ -42,10 +43,12 @@ class Item(object):  # pylint: disable=R0902,R0904
     EXTENSIONS = '.yml', '.yaml'
 
     DEFAULT_LEVEL = (1, 0)
+    DEFAULT_ACTIVE = True
+    DEFAULT_NORMATIVE = True
+    DEFAULT_DERIVED = False
     DEFAULT_TEXT = ""
     DEFAULT_REF = ""
     DEFAULT_LINKS = set()
-    DEFAULT_NORMATIVE = True
 
     auto = True  # set to False to delay automatic save until explicit save
 
@@ -78,10 +81,12 @@ class Item(object):  # pylint: disable=R0902,R0904
         self.root = root
         self._exists = True
         self._level = Item.DEFAULT_LEVEL
+        self._active = Item.DEFAULT_ACTIVE
+        self._normative = Item.DEFAULT_NORMATIVE
+        self._derived = Item.DEFAULT_DERIVED
         self._text = Item.DEFAULT_TEXT
         self._ref = Item.DEFAULT_REF
         self._links = Item.DEFAULT_LINKS
-        self._normative = Item.DEFAULT_NORMATIVE
         self._data = {}
 
     def __repr__(self):
@@ -103,20 +108,21 @@ class Item(object):  # pylint: disable=R0902,R0904
         return self.level < other.level
 
     @staticmethod
-    def new(path, root, prefix, digits, number, level, auto=None):  # pylint: disable=R0913
+    def new(path, root, prefix, sep, number, digits, level, auto=None):  # pylint: disable=R0913
         """Create a new item.
 
         @param path: path to directory for the new item
         @param root: path to root of the project
         @param prefix: prefix for the new item
-        @param digits: number of digits for the new document
+        @param sep: separator between prefix and number
         @param number: number for the new item
+        @param digits: number of digits for the new document
         @param level: level for the new item (None for default)
         @param auto: enables automatic save
 
         @raise DoorstopError: if the item already exists
         """
-        identifier = join_id(prefix, digits, number)
+        identifier = join_id(prefix, sep, number, digits)
         filename = identifier + Item.EXTENSIONS[0]
         path2 = os.path.join(path, filename)
         # Create the initial item file
@@ -156,10 +162,12 @@ class Item(object):  # pylint: disable=R0902,R0904
             raise DoorstopError(msg)
         # Store parsed data
         self._level = convert_level(self._data.get('level', self._level))
+        self._active = bool(self._data.get('active', self._active))
+        self._normative = bool(self._data.get('normative', self._normative))
+        self._derived = bool(self._data.get('derived', self._derived))
         self._text = self._data.get('text', self._text).strip()
         self._ref = self._data.get('ref', self._ref)
         self._links = set(self._data.get('links', self._links))
-        self._normative = bool(self._data.get('normative', self._normative))
         # Set meta attributes
         setattr(self, '_loaded', True)
 
@@ -178,15 +186,19 @@ class Item(object):  # pylint: disable=R0902,R0904
         if len(self._level) == 2:
             level = float(level)
         text = Literal(sbd(self._text))
+        active = self._active
+        normative = self._normative
+        derived = self._derived
         ref = self._ref.strip()
         links = sorted(self._links)
-        normative = self._normative
         # Build the data structure
         self._data['level'] = level
+        self._data['normative'] = normative
+        self._data['derived'] = derived
+        self._data['active'] = active
         self._data['text'] = text
         self._data['links'] = links
         self._data['ref'] = ref
-        self._data['normative'] = normative
         # Dump the data to YAML
         dump = yaml.dump(self._data, default_flow_style=False)
         # Save the YAML to file
@@ -251,6 +263,61 @@ class Item(object):  # pylint: disable=R0902,R0904
             del level[-1]
         return len(level)
 
+    @property
+    @auto_load
+    def active(self):
+        """Indicates the item should be considered for linking.
+
+        Inactive items are intended to be used for:
+         - future requirements
+         - temporarily disabled requirements or tests
+         - externally implemented requirements
+
+        """
+        return self._active
+
+    @active.setter
+    @auto_save
+    def active(self, status):
+        """Set the item's active status."""
+        self._active = bool(status)
+
+    @property
+    @auto_load
+    def normative(self):
+        """Get the item's normative status.
+
+        A non-normative item should not have or be linked to.
+        Non-normative items are intended to be used for:
+         - headings
+         - comments
+
+        """
+        return self._normative
+
+    @normative.setter
+    @auto_save
+    def normative(self, status):
+        """Set the item's normative status."""
+        self._normative = bool(status)
+
+    @property
+    @auto_load
+    def derived(self):
+        """Get the item's derived status.
+
+        A derived item does not have links to items in its parent
+        document, but should still be linked to by items in its child
+        document.
+        """
+        return self._derived
+
+    @derived.setter
+    @auto_save
+    def derived(self, status):
+        """Set the item's derived status."""
+        self._derived = bool(status)
+
     @property
     def header(self):
         """Indicates if the item is a header."""
@@ -292,18 +359,6 @@ class Item(object):  # pylint: disable=R0902,R0904
         """Set the items this item links to."""
         self._links = set(links)
 
-    @property
-    @auto_load
-    def normative(self):
-        """Get the item's normative status."""
-        return self._normative
-
-    @normative.setter
-    @auto_save
-    def normative(self, status):
-        """Set the item's normative status."""
-        self._normative = bool(status)
-
     # extended attributes ####################################################
 
     @auto_load
@@ -346,6 +401,10 @@ class Item(object):  # pylint: disable=R0902,R0904
         logging.info("checking item {}...".format(self))
         # Verify the file can be parsed
         self.load()
+        # Skip inactive items
+        if not self.active:
+            logging.info("skipped inactive item: {}".format(self))
+            return True
         # Check text
         if not self.text and not self.ref:
             logging.warning("no text: {}".format(self))
@@ -368,7 +427,9 @@ class Item(object):  # pylint: disable=R0902,R0904
     def _check_document(self, document):
         """Check the item against its document."""
         # Verify an item has upward links
-        if document.parent and self.normative and not self.links:
+        if all((document.parent,
+                self.normative,
+                not self.derived)) and not self.links:
             logging.warning("no links: {}".format(self))
         # Verify an item's links are to the correct parent
         for identifier in self.links:
@@ -387,26 +448,30 @@ class Item(object):  # pylint: disable=R0902,R0904
             except DoorstopError:
                 msg = "{} linked to unknown item: {}".format(self, identifier)
                 raise DoorstopError(msg) from None
-            identifier = item.id  # format the item ID
+            # TODO: not sure if we want this warning
+            # if not item.active:
+            #    logging.warn("{} linked to inactive item: {}".format(self,
+            #                                                         item))
+            identifier = item.id  # re-format the item's ID
             logging.debug("found linked item: {}".format(identifier))
             identifiers.append(identifier)
         self._links = set(identifiers)
         # Verify an item has downward (reverse) links
-        links = []
+        rlinks = []
         children = []
         for document in tree:
             if document.parent == self.prefix:
                 children.append(document)
                 for item in document:
                     if self.id in item.links:
-                        links.append(item.id)
-        if links:
+                        rlinks.append(item.id)
+        if rlinks:
             if self.normative:
-                msg = "down links: {}".format(', '.join(links))
+                msg = "down links: {}".format(', '.join(rlinks))
                 logging.debug(msg)
             else:
-                for link in links:
-                    msg = "{} links to non-normative {}".format(link,
+                for rlink in rlinks:
+                    msg = "{} links to non-normative {}".format(rlink,
                                                                 self)
                     logging.warning(msg)
         elif self.normative:
@@ -491,23 +556,28 @@ def split_id(text):
     ('ABC', 123)
 
     >>> split_id('ABC.HLR_01-00123')
-    ('ABC.HLR_01-', 123)
+    ('ABC.HLR_01', 123)
 
     """
     match = re.match(r"([\w.-]*\D)(\d+)", text)
     if not match:
         raise DoorstopError("invalid ID: {}".format(text))
-    return match.group(1), int(match.group(2))
+    prefix = match.group(1).rstrip(settings.SEP_CHARS)
+    number = int(match.group(2))
+    return prefix, number
 
 
-def join_id(prefix, digits, number):
+def join_id(prefix, sep, number, digits):
     """Join the parts of an item's ID into an ID.
 
-    >>> join_id('ABC', 5, 123)
+    >>> join_id('ABC', '', 123, 5)
     'ABC00123'
 
+    >>> join_id('REQ.H', '-', 42, 4)
+    'REQ.H-0042'
+
     """
-    return "{}{}".format(prefix, str(number).zfill(digits))
+    return "{}{}{}".format(prefix, sep, str(number).zfill(digits))
 
 
 def convert_level(text):
