@@ -68,7 +68,9 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
     def test_save_empty(self):
         """Verify saving calls write."""
         self.item.save()
-        text = ("level: 1.0" + '\n'
+        text = ("active: true" + '\n'
+                "derived: false" + '\n'
+                "level: 1.0" + '\n'
                 "links: []" + '\n'
                 "normative: true" + '\n'
                 "ref: ''" + '\n'
@@ -162,6 +164,24 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
         self.assertIn("level: 42.0\n", self.item._write.call_args[0][0])
         self.assertEqual((42, 0), self.item.level)
 
+    def test_active(self):
+        """Verify an item's active status can be set and read."""
+        self.item.active = 0  # converted to False
+        self.assertIn("active: false\n", self.item._write.call_args[0][0])
+        self.assertFalse(self.item.active)
+
+    def test_normative(self):
+        """Verify an item's normative status can be set and read."""
+        self.item.normative = 0  # converted to False
+        self.assertIn("normative: false\n", self.item._write.call_args[0][0])
+        self.assertFalse(self.item.normative)
+
+    def test_derived(self):
+        """Verify an item's normative status can be set and read."""
+        self.item.derived = 1  # converted to True
+        self.assertIn("derived: true\n", self.item._write.call_args[0][0])
+        self.assertTrue(self.item.derived)
+
     def test_text(self):
         """Verify an item's text can be set and read."""
         self.item.text = "abc "
@@ -234,12 +254,6 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
         self.item.remove_link('abc')
         self.assertEqual(['123'], self.item.links)
 
-    def test_normative(self):
-        """Verify an item's normative status can be set and read."""
-        self.item.normative = 0  # converted to False
-        self.assertIn("normative: false\n", self.item._write.call_args[0][0])
-        self.assertFalse(self.item.normative)
-
     def test_extended(self):
         """Verify an extended attribute can be used."""
         self.item.set('ext1', 'foobar')
@@ -259,7 +273,7 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
     def test_new(self):
         """Verify items can be created."""
         MockItem._new.reset_mock()
-        item = MockItem.new(EMPTY, FILES, 'TEST', 5, 42, (1, 2, 3))
+        item = MockItem.new(EMPTY, FILES, 'TEST', '', 42, 5, (1, 2, 3))
         path = os.path.join(EMPTY, 'TEST00042.yml')
         self.assertEqual(path, item.path)
         self.assertEqual((1, 2, 3), item.level)
@@ -269,7 +283,7 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
     def test_new_special(self):
         """Verify items can be created with a specially named prefix."""
         MockItem._new.reset_mock()
-        item = MockItem.new(EMPTY, FILES, 'VSM.HLR_01-002-', 3, 42, (1,))
+        item = MockItem.new(EMPTY, FILES, 'VSM.HLR_01-002', '-', 42, 3, (1,))
         path = os.path.join(EMPTY, 'VSM.HLR_01-002-042.yml')
         self.assertEqual(path, item.path)
         self.assertEqual((1, 0), item.level)
@@ -278,7 +292,13 @@ class TestItem(unittest.TestCase):  # pylint: disable=R0904
     def test_new_existing(self):
         """Verify an exception is raised if the item already exists."""
         self.assertRaises(DoorstopError,
-                          Item.new, FILES, FILES, 'REQ', 3, 2, (1, 2, 3))
+                          Item.new, FILES, FILES, 'REQ', '', 2, 3, (1, 2, 3))
+
+    def test_check_inactive(self):
+        """Verify an inactive item is not checked."""
+        self.item.active = False
+        self.item.ref = "invalid" + "reference"  # addition to avoid match
+        self.assertTrue(self.item.check())
 
     def test_check_document(self):
         """Verify an item can be checked against a document."""
