@@ -116,7 +116,7 @@ class Tree(object):
                 raise DoorstopError(msg)
             self.document = doc
 
-        elif doc.parent == self.document.prefix:
+        elif doc.parent.lower() == self.document.prefix.lower():
 
             # Current document is the parent
             node = Tree(doc, self)
@@ -147,11 +147,12 @@ class Tree(object):
 
     # actions ################################################################
 
-    def new(self, path, prefix, parent=None, digits=None):
+    def new(self, path, prefix, sep=None, parent=None, digits=None):
         """Create a new document and add it to the tree.
 
         @param path: directory path for the new document
         @param prefix: document's prefix
+        @param sep: separator between prefix and number for items
         @param parent: parent document's prefix
         @param digits: number of digits for the document's numbers
 
@@ -159,7 +160,7 @@ class Tree(object):
 
         @raise DoorstopError: if the document cannot be created
         """
-        document = Document.new(path, self.root, prefix,
+        document = Document.new(path, self.root, prefix, sep=sep,
                                 parent=parent, digits=digits)
         try:
             self._place(document)
@@ -311,7 +312,7 @@ class Tree(object):
 
         @raise DoorstopError: on issue
         """
-        logging.info("checking document tree...")
+        logging.info("checking tree...")
         for document in self:
             document.check(tree=self, ignored=self.vcs.ignored)
         return True
@@ -360,12 +361,12 @@ def build(cwd=None, root=None):
             path = os.path.join(dirpath, dirname)
             _add_document_from_path(path, root, documents)
 
-    # Build the document tree
+    # Build the tree
     if not documents:
         logging.warning("no documents found in: {}".format(root))
     logging.info("building tree...")
     tree = Tree.from_list(documents, root=root)
-    logging.info("final tree: {}".format(tree))
+    logging.info("built tree: {}".format(tree))
     return tree
 
 
